<?php
# Obtain global settings for gcdb
require("gcdb-settings.php");

# This program calls abstract DB interfaces

# If the required module is not found, gcdb will show you which
# extensions it found.
if(!(extension_loaded($RDBM))) {
	echo "<pre>PHP has these loaded extensions:\n";
	print_r (get_loaded_extensions());
        echo "</pre>";
	die ("Support not enabled for $RDBM, <b>gcdb</b> cannot run.\n");
}

# Install the proper DB hooks 
require("dbint/$RDBM.php");

###############################################################################
# DB COMMON FUNCTIONS :: NEW PEAR::DB IN USE
###############################################################################
# name: fetch_assoc
# Fetches an associated array from
# TABLE: $tbl
#    KEY=$dkey  VALUE=$dval
function fetch_assoc($tbl,$dkey,$dval) {
	global $db;

	$sql="SELECT ".$dkey.",".$dval." FROM ".$tbl;
	$res=$db->getAssoc($sql);
	check_error($res,"fetch assoc",$sql,1);

	return $res;
}

# name: getacl
# Pull ACL info
# ACL info can be single keywords or
# colon separated keyword:values
# Example:
#   admin      -- grants admin privs
#   admin:0    -- revokes admin privs
#   imsdb.php:0 -- revokes program access
#   imsdb.php  -- grants access to this program
function getacl($uid) {
	global $db;

	$sql="SELECT * FROM UserACL WHERE UserID=".$uid;
	$res=$db->getCol($sql,"AccFlag");
	check_error($res,"getacl",$sql,1);
	$rarr=array();

	for($x=0;$x<count($res);$x++) {
		# check for :
		if (stristr($res[$x],":")) {
			list($dkey,$dval)=explode(":",$res[$x]);
			$rarr[$dkey]=$dval;
		} else {
			$rarr[$res[$x]]=true;
		}
	}

	return $rarr;
}

# name: UserInfo
#
# If argument is a UserID, it will return Username
# If argument is a non-number, it will try to return a UserID
function UserInfo($val) {
	global $db;

	$ret="";
	if (is_numeric($val)) {
		$ids=fetch_assoc("Users","UserID","Username");
		$ret=$ids[$val]; # Translate ID to Username
	} else {
		$ids=fetch_assoc("Users","Username","UserID");
		$ret=$ids[$val]; # Translate username to ID
	}

	return $ret;
}

# name: check_error
#
# arguments: result, traceback tag, sql statement, return flag
#
# returns: nothing, program dies if return flag is non-zero
#
function check_error($res,$caller,$sql,$dflag) {
	if (DB::iserror($res)) {
		if ($_SESSION['sess_acl']['debug_dest']=="syslog") {
			pdebug("check_error:$caller:SQL($sql)",LOG_DEBUG);
			$msg = $res->getMessage();
			pdebug($msg,LOG_DEBUG);
		} else {
			echo "check_error:$caller:SQL($sql)\n";
			echo $res->getMessage()."\n";
		}
		if ($dflag) {
			die();
		} else {
			# Indicate that there was an error
			return 1; 
		}
	}
	# An error was not detected
	return 0;
}

# name: getDBConnection
#
# arguments: none
# returns: database handle
#
# desc: I did this so the DB could easily be changed
function getDB2Connection () {
	global $PERSISTENT, $DBHOST, $DBUSER, $DBPASSWORD, $DBNAME, $RDBM;

	# Use new PEAR interface

	$cstr="$RDBM://$DBUSER:$DBPASSWORD@$DBHOST/$DBNAME";
	$db=DB::connect($cstr);
	if (DB::iserror($db)) {
		die($db->getMessage());
	}

	return $db;
}
function getDBConnection () {
	global $db;
	return $db;
}

# name: DBquery
#
# arguments: connection, SQL query
# returns: 
#   SQL SELECT : Result object for select is returned or 0 for error
#   OTHER SQL  : 0 for failure, error object or non-zero for rows affected
#
# desc: Sends a query to the database
function DBquery($query,$db) {
	global $PHP_SELF;
	if ($_SESSION['sess_acl']['debug']) {
		pdebug($query,LOG_DEBUG);
	}
	$result=$db->query($query);
	$res=check_error($result,"DBquery",$PHP_SELF,0);
	if ($res) {
		return 0;  # zero indicates error
	}
	return $result;
}

# name: DBfree
#
# arguments: database or result handle
# returns: nothing
#   This routine helps free up resources.  There are
#   times we would like to free up a handle, but we
#   need to check if a handle actually exists.
function DBfree($handle) {
	if (DB::iserror($handle)) {
		return;  # there is an error
	}
	if (is_integer($handle) && $handle==0) {
		return;  # also an error, DBquery can return 0
	}
	if (is_integer($handle) && $handle>0) {
		# no error, handle is nothing more than the number of rows affected
		return;  
	}
	$handle->free();
}

# name: DBfetch_array
#
# arguments: Result set
# returns: associative array
#
# desc: Creates an associative array from a result
function DBfetch_array($result) {
	$row = "";
	$res = check_error($result,"DBfetch_array","NA",1);
	if ($res==0) {
		$row = $result->fetchRow(DB_FETCHMODE_ASSOC);
	}
	return $row;
}

# name: DBnum_rows
#
# arguments: Result handle
# returns: Number of rows in the result
#
# Returns the number of rows in a result
function DBnum_rows($result) {
	$count = $result->numRows();
	return $count;
}

# name: checkDBError
# status: depricated? is not usable with PEAR::DB
#
# arguments: database handle
# returns: String containing DB Error number and Error String
#
# desc: Checks for an error with the DB and prints the error if it exists
function checkDBError($db) {
	if (!$db) {
		die ("Need a valid database connection!<br>\n");
	}
	$test = rdbms_db_error($db);
	if($test != "") {
		echo "$test<br>";
	}
}

# name: DBinsert_id
#
# arguments: result handle, table name, field name, database handle
# returns: The ID that was assigned by the last insert statement
#
# desc: Returns the ID given to the last insert
function DBinsert_id($result, $table, $field, $db) {
	$num = rdbms_insert_id($result, $table, $field, $db);
	return $num;
}

# name: DBReport
#
# arguments: Result set, Title of action, URL to return to, Text for return link,
#             database handle
# returns: HTML table for showing the result of an update
#
# desc: Uses the PrettyTable functions to generate a table detailing what happened
function DBReport ($result, $title, $return_url, $return_link, $db) {
	global $lUpdateSuccess, $lUpdateFailed;
	if(!(is_integer($result)) or ($result == 1)) {
		beginPrettyTable("1", $title);
		echo "<tr>\n";
		echo " <td><div class=data>$lUpdateSuccess <a href='$return_url'>$return_link</a></div></td>\n";
		echo "</tr>\n";
		endPrettyTable();
	} else {
		beginPrettyTable("1", $title);
		echo "<tr> <td><div class=data>$lUpdateFailed: ";
		echo checkDBError($db);
		echo "</div></td></tr>\n";
		endPrettyTable();
	}
}

# name: MKarrayfordrop
# Make an array suitable for a DROP BOX
#
# arguments: result handle, key and value index
#
function MKarrayfordrop ($result, $idxkey, $idxval) {
	$tarr = array();
	while($res_row = DBfetch_array($result)) {
		array_push($tarr, $res_row[$idxkey]);
		array_push($tarr, $res_row[$idxval]);
	}
	return $tarr;
}

# name: MKassocarray
# Make an array suitable for recalling data
#
# arguments: result handle, key and value index
#
function MKassocarray ($result, $idxkey, $idxval) {
	$tarr = array();
	while($res_row = DBfetch_array($result)) {
		$tarr[$res_row[$idxkey]]=$res_row[$idxval];
	}
	return $tarr;
}

?>
