<?php
# This file contains lots of functions used by the billing database
# to generate no fun things like tables, forms, and such.
require_once("gcdb-settings.php");

# Check program depth; this helps modules work
if (!isset($pgm_depth)) {
	$pgm_depth="";
}

###############################################################################
# DB INTERFACE
###############################################################################
# PEAR::DB
require_once("DB.php");
require_once("db.php");

# Open db connection once and use it throughout
$db = getDB2Connection();

###############################################################################
# BILLING FUNCTIONS
###############################################################################

# name: numfmt
#
# arguments: format type [money, rate, etc]
# returns: appropriate format
function numfmt($fmt_type) {
	if ($fmt_type=="money") {
		$x="deci_".$fmt_type;
		$fmt="%.".$_SESSION['sess_acl'][$x]."f";
		return $fmt;
	}
}

# name: untranslate_interval
#
# arguments: Language version of the Charged field
# returns: DB version of charged field (English)
#  
# desc: This function allows gcdb to have a language neutral way of storing
# desc: the interval for charging an account.
function untranslate_interval($charged) {
	global $lMonthly, $lQuarterly, $lBiannually, $lAnnually;
	if($charged == $lMonthly) {
		return "monthly";
	}
	if($charged == $lQuarterly) {
		return "quarterly";
	}
	if($charged == $lBiannually) {
		return "biannually";
	}
	if($charged == $lAnnually) {
		return "annually";
	}
}

# name: translate_interval
#
# arguments: DB version of charged field (English)
# returns: Language version of the Charged field
#  
# desc: translates the DB interval into a Lang string
function translate_interval($charged) {
	global $lMonthly, $lQuarterly, $lBiannually, $lAnnually;
	if($charged == "monthly") {
		return $lMonthly;
	}
	if($charged == "quarterly") {
		return $lQuarterly;
	}
	if($charged == "biannually") {
		return $lBiannually;
	}
	if($charged == "annually") {
		return $lAnnually;
	}
}

# name: pkg_cost
#
# arguments: PackageID
# returns:   Computed cost based on resource ID and package ID row info
function pkg_cost($pkgID) {
	global $db;
	$sql = "SELECT * FROM Package WHERE PackageID=$pkgID";
	$res = DBquery($sql, $db);
	$pkg_row = DBfetch_array($res);
	DBfree($res);
	$resID = $pkg_row["ResourceID"];
	$sql = "SELECT * FROM Resources WHERE ResourceID=$resID";
	$res = DBquery($sql, $db);
	$res_row = DBfetch_array($res);
	DBfree($res);
	# get base price
	if (isset($pkg_row["Price"])) {
		$cost = $pkg_row["Price"];
	} else {
		$cost = $res_row["Price"] * $pkg_row["Quantity"];
	}
	# apply discount
	if (isset($pkg_row["Disc"])) {
		if ($pkg_row["DiscType"]=="Rate") {
			$cost = $cost - ($cost * ($pkg_row["Disc"]/100.0));
		} else {
			$cost = $cost - $pkg_row["Disc"];
		}
	}
	# taxes applied at billing when applied to specific accounts and customers
	return $cost;
}

###############################################################################
# DOCUMENT FUNCTIONS
###############################################################################

# name: beginDocument 
#
# arguments: Page title, Username
# returns: None
#
# desc: echos the HTML tags that get the document started, provides a central
# desc: location for the background color, stylesheets, and whatnot.
function beginDocument ($title, $user) {
	
	global $BRAND, $BACKGROUND, $TOPBAR, $sess_lang, $sess_admin, $lAdmin, $lHome;
	global $pgm_depth;

	if(isset($sess_lang)) {
		checkLang($sess_lang);
	}
	echo "<html>\n";
	echo "<head>\n <title>[$BRAND] :: $title</title>\n";
	echo " <link rel=stylesheet href='".$pgm_depth."gcdb.css' type='text/css'>\n";
	echo "</head>\n<body bgcolor='$BACKGROUND' text='black' leftmargin=0 topmargin=0 marginheight=0 marginwidth=0>\n"; 
	echo "<table bgcolor='$TOPBAR' width=100%><tr><td width='80%' align='left' class='header'>&nbsp;&nbsp;$BRAND: $user</td><td width='20%' align='right'>";
	if($user != "Not Logged In") {
		if($_SESSION['sess_acl']['admin']) {
			echo "<a href='".$pgm_depth."administration.php'>";
				d_img("configuration", $lAdmin, "border=0");
			echo "</a>";
		}
		echo "<a href='".$pgm_depth."main.php'>";
    	d_img("home",$lHome,"border=0");
		echo "</a>";
	}
	echo "&nbsp;&nbsp;</td></tr></table>";
	echo "<table cellpadding=0 width='100%' height='100%' border=0><tr><td valign=top>\n";
}

# name: searchBar
#
# arguments: None
# returns: None
#
# desc: echos the HTML for the search Bar
function searchBar() {
	global $lSearch, $lLast, $lAddress, $lEmail, $lDomain, $lAccount;
	openForm("searcher", "search.php");
		beginPrettyTable("2");
		echo "<tr>\n";
		echo "<td><b>$lSearch</b>: <input name='tosearch' type='text'></td>\n";
		echo "<td valign='center'>\n<select name='searcher' type='text'>\n";
		echo " <option value='last' selected>$lLast\n";
		echo " <option value='address'>$lAddress\n";
		echo " <option value='email'>$lEmail\n";
		echo " <option value='account'>$lAccount\n";
		echo " <option value='domain'>$lDomain\n";
		echo "</select>\n";
		echo "<input type='image' align='center' src='images/go.png' value='submit' border=0>\n";
		echo "</td></tr>\n";
		endPrettyTable();
		closeForm();
}

# name: endDocument
# 
# arguments: None
# returns: None
#
# desc: closes all the HTML opened by beginDocument
function endDocument() {
	echo "</td></tr></table></body></html>\n";
}
	

###############################################################################
# TABLE FUNCTIONS
###############################################################################

# name: beginPrettyTable
#
# desc: handle the creation of a pretty, outlined table.  Uses the supplied
# desc: bordercolor, bgcolor, colspan (for header) and text (text of header)
function beginPrettyTable () {
	global $TABLEBORDER, $INNERTABLE;

	# Allow us to take either 1 or 2 arguments
	$numargs = func_num_args();
	if($numargs == 0) {
		die ("Must provide a colspan to beginPrettyTable()\n");
	}
	$arg_list = func_get_args();
	$colspan = $arg_list[0];
	if($numargs > 1) {
		$header = $arg_list[1];
	}
	echo "<table bgcolor='$TABLEBORDER' cellpadding=1 cellspacing=0 border=0>\n";
	if ($header) {
		echo " <tr> <td colspan=$colspan align='right'><div class='header'>$header&nbsp;</div></td> </tr>\n";
	}
	echo " <tr>\n  <td>\n";
	echo "   <table bgcolor='$INNERTABLE' cellpadding=2 cellspacing=0 border=0>\n";
	echo "    <tr>\n  <td>\n";
	echo "      <table bgcolor='$INNERTABLE' cellpadding=2 cellspacing=0 border=0>\n";
}

# name: endPrettyTable
#
# desc: close all tags opened by beginPrettyTable
function endPrettyTable () {
	echo "      </table>\n";
	echo "     </td> </tr>\n";
	echo "   </table>\n";
	echo "  </td> </tr>\n";
	echo "</table>\n";
}

# name: beginBorderedTable
#
# desc: when used in unison with beginPrettyTable, gives a nice visual cue around
# desc: the data inside a table
function beginBorderedTable ($colspan) {
	global $TABLEBORDER, $INNERTABLE;

	echo "<tr>\n  <td>\n";
	echo " <table bgcolor='$INNERTABLE' cellpadding=2 cellspacing=2 border=0>\n";
}

# name: endBorderedTable
#
# desc: close all tags opened by beginBorderedTable
function endBorderedTable () {
	echo "   </td> </tr>\n";
	echo "  </table>\n";
	echo " </td> </tr>\n";
}

###############################################################################
# FORM FUNCTIONS
###############################################################################

# name: openForm
#
# desc: creates a form
function openForm ($name, $action) {
	echo "<form method='post' name='$name' action='$action'>";
}

# name: makeHiddenField
#
# desc: creates a hidden field
function makeHiddenField ($field, $value) {
	echo "<input type=\"hidden\" name=\"$field\" value=\"$value\">\n";
}

# name: makeStaticField
#
# desc: creates an uneditable field
function makeStaticField ($field, $value) {
	echo " <tr> <td><b>$field:</b></td><td><div class='data'>$value</div></td> </tr>\n";
}

# name: makeTextField
#
# arguments: Field label, form name, value
# returns: none
#
# desc: creates a textfield with the supplied paramaters
function makeTextField ($field, $name, $value) {
	echo " <tr> <td><b>$field:</b></td><td><input name=\"$name\" type='text' value=\"$value\"></td> </tr>\n";
}

# name: makePasswordField
#
# arguments: Field label, form name, value
# returns: none
#
# desc: creates a textfield with the supplied paramaters
function makePasswordField ($field, $name, $value) {
	echo " <tr> <td><b>$field:</b></td><td><input name='$name' type='password' value=\"$value\"></td> </tr>\n";
}

# name: makeLargeTextField
#
# desc: creates a textarea with the supplied parameters
function makeLargeTextField ($field, $name, $value) {
	echo "<tr>";
		echo "<td valign='top'><b>$field:</b></td>";
		echo "<td><textarea name=$name cols='48' rows='15' wrap='physical'>$value</textarea></td>";
	echo "</tr>\n";
}

# name: makeDropBox
#
# desc: creates a select control using the supplied options, rearranging them
# desc: according to the first arg passed
function makeDropBox () {
	$numargs = func_num_args();
	if($numargs < 3) {
		echo $numargs."-";
		die ("Must provide arguments to makeDropBox\n");
	}
	$arg_list = func_get_args();
	$field 	= $arg_list[0];
	$name 	= $arg_list[1];
	$current = $arg_list[2];
	echo " <tr> <td><b>$field:</b></td><td><select name='$name'>\n";
	for($i = 3; $i < $numargs; $i++) {
		if($arg_list[$i] != $current) {
			echo "<option value='$arg_list[$i]'>$arg_list[$i]\n";
		} else {
			echo "<option value='$arg_list[$i]' selected>$arg_list[$i]\n";
		}
	}
	echo "</select></td></tr>\n";
}

# name: makeArrayDropBox
#
# desc: creates a select control from an array, but its a special array ;)
function makeArrayDropBox ($field, $name, $current, $array) {
	echo " <tr> <td><b>$field:</b></td><td><select name='$name'>\n";
	$size = sizeof($array);
	for($i = 0; $i < $size; $i += 2) {
		$also = $i + 1;
		if($array[$also] != $current) {
			echo "<option value='$array[$i]'>$array[$also]\n";
		} else {
			echo "<option value='$array[$i]' selected>$array[$also]\n";
		}
	}
	echo "</select></td></tr>\n";
}

# name: makeCheckBox
#
# arguments: none
# returns: none
#
# desc: makes a check box field
function makeCheckBox ($field, $name, $value,$checked) {
	echo "<tr>";
		echo "<td><b>$field:</b></td>";
		echo "<td><input name='$name' type='checkbox'  value='$value' $checked></td>";
	echo "</tr>\n";
}


# name: makeSubmitter
#
# arguments: none
# returns: none
#
# desc: makes a submit field
function makeSubmitter () {
	echo "<tr>";
		echo "<td colspan=2 align=center>\n";
			echo "<input type=image type='submit' value='submit' src='images/submit.png' border=0 alt='Go!'>";
		echo "</td>";
	echo "</tr>\n";
}

# name: closeForm
#
# arguments: none
# returns: none
#
# desc: close a form
function closeForm () {
	echo "</form>";
}

###############################################################################
# SECURITY FUNCTIONS
###############################################################################

# name: adminify
#
# arguments: User, Admin status
# returns: none
#
# desc: restrict access to a page to only Admins
function adminify($sess_user, $sess_admin) {
	global $lAccessDenied, $lAdminUseOnly;
	if(!isset($_SESSION['sess_acl']["admin"])) {
		beginDocument("Security", $_SESSION['sess_user']);
		beginPrettyTable(1, "$lAccessDenied");
		echo "<tr><td>$lAdminUseOnly</td></tr>";
		endPrettyTable();
		endDocument();
		die();
	}
}	

# name: aclcheck
# arguments: acl item to check
# returns: none
#
# desc: item must exist or the user is thrown out
function aclcheck($aclitem) {
	global $lAdminUseOnly, $lAccessDenied, $sess_user;
	if (!isset($_SESSION['sess_acl'][$aclitem])) {
	beginDocument("Security", $_SESSION['sess_user']);
		beginPrettyTable(1, "$lAccessDenied");
		echo "<tr><td>You must have ACL($aclitem) to use this section.</td></tr>";
		endPrettyTable();
		endDocument();
		die();
	}
}

###############################################################################
# LANGUAGE API
###############################################################################

# name: checkLang
#
# arguments: Language
# returns: none
#
# desc: Adds content type header for languages that need it
function checkLang($lang) {
	if(isset($HTTPcharser)) {
		    header("Content-Type: text/html; charset=".$HTTPcharset);
	} else {
	    # Ugly hack. Don't use.
	    if($lang == "russian.php") {
		    header("Content-Type: text/html; charset=koi8-r");
	    }
	}
}

if(!(isset($sess_lang))) {
 	$result = DBquery("SELECT * FROM Configuration",$db);
	$config_row = dbfetch_array($result);
	require($pgm_depth."lang/".$config_row["LoginLang"]);
} else {
	require($pgm_depth."lang/".$sess_lang);
}

###############################################################################
# DEBUG API
###############################################################################

# name: pdebug
#
# arguments: string, optional priority
# returns: none
#
# desc: used for sending message in HTML or to syslog for debugging
function pdebug($msg, $pri) {
	$dest=$_SESSION['sess_acl']['debug_dest'];
	if ($msg) {
		switch($dest) {
			// write it into the html
			case "html":
				echo "<!-- $msg -->\n";
				break;
			// write it into the system log
			case "syslog":
				$dpri = LOG_DEBUG;
				if ($pri) {
					$dpri = LOG_DEBUG | $pri;
				}
				openlog("gdbc", LOG_PID, LOG_USER);
				syslog($dpri,$msg);
				closelog();
				break;
		}
	}
}

###############################################################################
# GENERIC API
###############################################################################

# name: d_img(alias, words, html)
#
# arguments:
#   alias : name given to image/icon
#   words : fills in the HTML ALT TAG
#   html : allows insertion of other HTML code
#
# example: 
#   d_img("edit", $lEdit, "border=1");
#
#   conf_images DB : "edit" is "edit.png" width=24 height=24
#                    "PATH" is "images"
#
#   Will generate HTML code: <img src="images/edit.png" height=24 width=24 alt="Edit" border=1>
#
# desc: new image/icon management for gcdb
#
function d_img($alias, $words, $html) {
	global $db;
	global $pgm_depth;

	$imgpath=$_SESSION['sess_acl']['image_path'];
	
	# if this is NULL, then the real default is images
	if ($imgpath=="") {
		$imgpath="images";
	}

	# Which PNG to use!
	$rpng = $db->query("SELECT * FROM conf_images WHERE alias='$alias'");
	$rowpng = DBfetch_array($rpng);
	$png = $pgm_depth.$imgpath."/".$rowpng["src"];

	#echo "[$alias $words $html $png]";
	if (file_exists($png)) {
		echo "<img src=\"$png\"";
		echo " width=".$rowpng["width"];
		echo " height=".$rowpng["height"];
		if ($words) {
			echo " alt=\"$words\"";
		}
		if ($html) {
			echo " $html";
		}
		echo ">";
	}

}

# name: switchLogic
#
# desc: switches the order of queries

function switchLogic ($logic)
{
	if ($logic == "DESC") {
	  $logic = "ASC";
	} else {
	  $logic = "DESC";
	}
	return $logic;
}
?>
